<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/ecrire_?lang_cible=my
// ** ne pas modifier le fichier **

return [

	// A
	'activer_plugin' => 'ထပ်ထည့်သည့် pluginကို အ​တည်ပြုရန်',
	'aide_non_disponible' => 'ယခုသုံးသော ဘာသာဖြင့်ရှာဖွေ၍မရသေးပါ',
	'auteur' => 'ရေးသားသူ',
	'avis_acces_interdit' => '​ဝင်ရောက်သုံးစွဲခွင့်တားမြစ်ထားသည်',
	'avis_article_modifie' => 'သတိပေးချက်၊ လွန်ခဲ့သော မိနစ် @date_diff@ တွင် @nom_auteur_modif@ သည် ဆေင်းပါးတွင် အလုပ်လုပ်ခဲ့ပြီးဖြစ်သည်',
	'avis_aucun_resultat' => 'မတွေ့ရှိပါ',
	'avis_chemin_invalide_1' => 'သင်ရွေးချယ်ခဲ့သည့် အခန်းကဏ္ဍ',
	'avis_chemin_invalide_2' => 'ရနိုင်မည့်ပုံမပေါ်ပါ။ အရင်စာမျက်နှာသို့ ပြန်သွားပြီး အချက်လက်များကို ပြန်စစ်ဆေးပါ',
	'avis_connexion_echec_1' => ' MySQL ဆာဗာသို့ ဆက်သွယ်မှု မအောင်မြင်ပါ', # MODIF
	'avis_connexion_echec_2' => 'အရင်စာမျက်နှာသို့ ပြန်သွားပြီး အချက်လက်များကို ပြန်စစ်ဆေးပါ',
	'avis_connexion_echec_3' => '<b>N.B.</b> MySQL အချက်လက် သိုလှောင်မှုကို  ဆာဗာအမှတ်​စဉ်တွင် အသုံးမပြုမီ အသက်သွင်းရန် <b>လိုအပ်ပါသည်</b> အကယ်၍ ဆက်သွယ်၍မရပါက သင်အမှန်တကယ် လိုအပ်မှုကို သေချာအောင်လုပ်ပါ', # MODIF
	'avis_connexion_ldap_echec_1' => 'LDAP ဆာဗာသို့ ဆက်သွယ်၍မရပါ',
	'avis_connexion_ldap_echec_2' => 'အရင်စာမျက်နှာသို့ ပြန်သွားပြီး အချက်လက်များကို ပြန်စစ်ဆေးပါ',
	'avis_connexion_ldap_echec_3' => 'သုံးစွဲသူအသစ်များ ထည့်သွင်းရန် LDAP ကို တခြားနည်းဖြင့် အသုံးမပြုပါနှင့်', # MODIF
	'avis_deplacement_rubrique' => 'သတိပေးချက်။ သည်အပိုင်းတွင် @contient_breves@ သတင်းစကား @scb@ ပါဝင်ပါသည်။ ၄င်းကို ဖယ်ရှားလိုပါက သည်လုပ်ဆောင်ချက်ကို ပြန်လည်အတည်ပြုပါ',
	'avis_erreur_connexion_mysql' => 'MySQL ချိတ်ဆက်မှု အခက်ခဲဖြစ်သည်',
	'avis_espace_interdit' => '<b>တားမြစ်နယ်မြေ</b> <div>SPIP ကို ထည့်သွင်းပြီးဖြစ်သည်</div>',
	'avis_lecture_noms_bases_1' => 'အချက်များကို ထည့်သွင်းသည့်ကိရိယာသည် ထည့်သွင်းနေသော အချက်လက်သိုလှေင်မှုများကို မဖတ်နိုင်ပါ',
	'avis_lecture_noms_bases_2' => 'အချက်လက်လည်းမရနိုင်ပါ (သို့) ခွင့်ပြုထားသော အချက်လက် စာရင်းလည်း လုံခြုံရေးကြောင့် မရနိုင်ပါ (ပင်မဆာဗာ တောင်းဆိုမှု များလွန်းသည်)',
	'avis_lecture_noms_bases_3' => 'ဤနေရာတွင် ဒုတိယရွေး​ချယ်မှုသည် မှန်ကန်ပါသည်။ သင့်ချိတ်ဆက် ဝင်ရောက်လို့ရပြီးနောက် အချက်လက်သိုလှောင်မှုကို အမည်ပေးထားနိုင်ပါသည်',
	'avis_non_acces_page' => 'ဤစာမျက်နှာကို အသုံးပြုခွင့်မရှိပါ',
	'avis_operation_echec' => 'လုပ်ဆောင်မှု မအောင်မြင်ပါ',
	'avis_operation_impossible' => 'လုပ်ဆောင်ရန် မဖြစ်နိုင်ပါ',
	'avis_suppression_base' => 'သတိပေးချက်၊ ဒေသာ ဖျက်သိမ်းမှုကို ပြန်ဖော်၍ရမည် မဟုတ်ပါ',

	// B
	'bouton_acces_ldap' => 'LDAP ကိုဆက်သွယ်ရန် လုပ်ပါ >>',
	'bouton_ajouter' => 'ထပ်ထည့်ပါ',
	'bouton_annuler' => 'ပယ်သည်',
	'bouton_demande_publication' => 'ဤဆောင်းပါး ထုတ်ဝေသည့်ရက်စွဲ လိုအပ်သည်',
	'bouton_desactive_tout' => 'အားလုံးမဖြစ်နိုင်ပါ',
	'bouton_effacer_tout' => 'အားလုံးကိုဖျက်ပစ်ပါ',
	'bouton_envoyer_message' => 'နောက်ဆုံးစာကို ပို့ပါ',
	'bouton_modifier' => 'ပြန်လည်ပြုပြင်မွမ်းမံသည်',
	'bouton_radio_afficher' => 'ပြပါ',
	'bouton_radio_apparaitre_liste_redacteurs_connectes' => 'ဆက်သွယ်သော စာတည်းများကို ပြပါ', # MODIF
	'bouton_radio_envoi_annonces_adresse' => 'ကြေငြာချက်များကို ဤလိပ်စာများသို့ ပေးပို့ရန်',
	'bouton_radio_envoi_liste_nouveautes' => 'နောက်ဆုံးရသတင်း စာရင်းကို ပေးပို့ရန်',
	'bouton_radio_non_apparaitre_liste_redacteurs_connectes' => 'အချိတ်အဆက်ရှိထားသော စာတည်းများစာရင်းတွင် မ​ပေါ်စေလိုပါ', # MODIF
	'bouton_radio_non_envoi_annonces_editoriales' => 'စာတည်းများ၏ ကြေငြာချက်များ ပေးပို့ရန်မလို',
	'bouton_redirection' => 'ပြန်လည်ရည်ညွှန်းသည်',
	'bouton_relancer_installation' => 'ပြန်လည် ထည့်သွင်းရန်',
	'bouton_suivant' => 'နောက်တစ်ခု',
	'bouton_tenter_recuperation' => 'ပြင်ဆင်ရန် ကြိုးပမ်းမှု',
	'bouton_test_proxy' => 'proxy ကိုစမ်းသပ်ရန်',
	'bouton_vider_cache' => 'မှတ်ဉာဏ်ကို ပျယ်ဖျက်ရန်',

	// C
	'cache_modifiable_webmestre' => 'ဤကန့်သတ်ချက်ကို webmasterမှ ပြန်လည်ပြုပြင်မွမ်းမံနိုင်သည်', # MODIF
	'calendrier_synchro' => '<b>iCal</b> နှင့်အတူ ပြက္ခဒိန် ကိုသင်အသုံးပြုလျှင် ဤဝက်ဘ်ဆိုက်၏ သတင်းအချက်လက်များနှင့် ၄င်းကို ​ချိတ်ဆက်နိုင်ပါသည်',
	'connexion_ldap' => 'ချိတ်ဆက်မှု',

	// D
	'date_mot_heures' => 'H',

	// E
	'email' => 'အီးမေးလ်',
	'email_2' => 'အီးမေးလ်',
	'entree_adresse_annuaire' => 'အညွှန်းလိပ်စာများ',
	'entree_adresse_email' => 'သင့်အီးမေးလ်လိပ်စာ',
	'entree_base_donnee_1' => 'အချက်လက်သိုလှောင်မှု လိပ်စာ',
	'entree_base_donnee_2' => '(တခါခါ ဤလိပ်စာသည် နာမည် «localhost» နှင့်ဆက်စပ်မှုရှိပြီး၊ တခါခါ ဘာမှမရှိဘဲဖြစ်နေသည်)',
	'entree_biographie' => 'ကိုယ်ရေးရာဇဝင် အကျဉ်းချုပ်',
	'entree_chemin_acces' => 'အခန်းကဏ္ဍထဲကို<b>ထည့်ပါ</b>',
	'entree_cle_pgp' => 'သင့် PGP ကီး',
	'entree_contenu_rubrique' => '(ပါဝင်သည့်အကြောင်းအရာ အကျဉ်းချုပ်)',
	'entree_identifiants_connexion' => 'သင့်ဆက်သွယ်မှုကို ဆန်းစစ်သူများ၊',
	'entree_informations_connexion_ldap' => 'LDAP အချက်လက်များဖြင့် ဖြည့်စွက်ပါ၊ လိုအပ်သောအချက်လက်များကို သင့်ကွန်ရက် ကြီးကြပ်သူထံမှ ရနိုင်ပါသည်', # MODIF
	'entree_infos_perso' => 'သင်ဘယ်သူလဲ?',
	'entree_interieur_rubrique' => 'အခန်းကဏ္ဍထဲတွင်',
	'entree_liens_sites' => '<b>ဆက်နွယ်မှု</b> (လေ့လာရန်ကိုး ကားဝက်ဘ်ဆိုက်)',
	'entree_login' => 'သင့်ဝင်ရောက်မှု',
	'entree_login_connexion_1' => 'ဆက်သွယ်မှုထဲသို့ ဝင်ရောက်မှု',
	'entree_login_connexion_2' => '(FTP ထဲဝင်ရောက်မှုသည် တခါတရံ တက်လိုက်ကျလိုက်ဖြစ်နေသည်)',
	'entree_mot_passe' => 'သင့်စကားဝှက်',
	'entree_mot_passe_1' => 'ဆက်သွယ်မှု စကားဝှက်',
	'entree_mot_passe_2' => '(FTP ထဲဝင်ရောက်မှု စကားဝှက်သည် တခါတရံ တက်လိုက်ကျလိုက်ဖြစ်နေသည)',
	'entree_nom_fichier' => 'ဖိုင်နာမည် @texte_compresse@ကို ထည့်ပါ',
	'entree_nom_pseudo' => 'သင့်အမည် (သို့) အမည်ကွဲ',
	'entree_nom_pseudo_1' => 'သင့်အမည် (သို့) အမည်ကွဲ',
	'entree_nom_site' => 'သင့်ဝက်ဘ်ဆိုက်နာမည်',
	'entree_nouveau_passe' => 'စကားဝှက်အသစ်',
	'entree_passe_ldap' => 'စကားဝှက်',
	'entree_port_annuaire' => 'အညွှန်း Port နံပါတ်',
	'entree_signature' => 'အမှတ်အသား',
	'entree_titre_obligatoire' => '<b>ခေါင်းစဉ်</b> [လိုအပ်ပါသည်]<br />',
	'entree_url' => 'သင့်ဝက်ဘ်ဆိုက်လိပ်စာ',
	'erreur_plugin_fichier_absent' => 'ဖိုင်ပျောက်သည်',
	'erreur_plugin_fichier_def_absent' => 'အဓိပ္ပါယ် ဖွင့်ဆိုချက်ဖိုင် ပျေက်နေသည်',
	'erreur_plugin_nom_fonction_interdit' => 'တားမြစ်ထားသော လုပ်ဆောင်ချက်နာမည်',
	'erreur_plugin_nom_manquant' => 'plugin နာမည်မရှိပါ',
	'erreur_plugin_prefix_manquant' => 'Plugin နာမည်အတွက် ဖော်ပြမထားပါ',
	'erreur_plugin_tag_plugin_absent' => '&lt;plugin&gt;အဓိပါယ် ဖွင့်ဆိုချက်ဖိုင်ထဲတွင် မရှိပါ',
	'erreur_plugin_version_manquant' => 'မူကွဲဝင်ရောက်ချိတ်ဆက်မှု ပျောက်နေသည်',

	// I
	'ical_info1' => '‘ဤစာမျက်နှာသည် ဤဝက်ဘ်ဆိုက်၏ လုပ်ဆောင်ချက်များကို နည်းအမျိုးမျိုးဖြင့် ထိန်းသိမ်းရန်ဖြစ်သည်',
	'ical_info2' => 'ပိုမိုစုံစုံလင်လင် သိရှိရန်<a href="@spipnet@">SPIP စာရွက်စာတမ်းများ</a> ကိုလာလည်ပါ။', # MODIF
	'ical_info_calendrier' => 'ပြက္ခဒိန် နှစ်ခုသည် သင့်၏ပစ်ပျယ်ခြင်း ပြုလုပ်မည့်​ စာရင်းထဲတွင်ရှိနေသည်။ ပထမ တခုကတော့ ထုတ်လွင့်ပြီးသားဆောင်းပါးများ စာရင်း၊နောက် တခုကတော့ စာတည်းအဖွဲ့၏ထုတ်ပြန် ကြေငြာချက်များနှင့် သင့်၏ကိုယ်ပိုင် စကားဝှက်ကို ပြန်လည်ပြင်ဆင်ရန် သတင်းစကားများပါဝင်သည်။',
	'ical_methode_http' => 'ဆွဲချရန်',
	'ical_methode_webcal' => 'ပူးတွဲချိတ်ဆက်မှု (webcal://)', # MODIF
	'ical_texte_prive' => 'ဤပြက္ခဒိန်သည် ကိုယ်ရေးကိုတာ ကိစ္စများ (အလုပ်၊ ချိန်းဆိုချက်များ၊ တင်သွင်းပြီး ဆောင်ပါးများ၊ သတင်းများ စသည်ဖြင့်)',
	'ical_texte_public' => 'ဤပြက္ခဒိန်သည် အများသုံးနိုင်ရန်ခွင့်ပြုသည် (အများဆိုင် ဆောင်းပါးများနှင့် သတင်းစကားများ)',
	'ical_texte_rss' => 'ဤဆိုက်၏​ နောက်ဆုံးရ သတင်းများကို XML/RSS (Rich Site Summary) တစ်ခုခုဖြင့် ပူးတွဲချိတ်ဆက်မှုပြုနိုင်ပါသည်။ ဤသို့အားဖြင့်လည်း တခြားဆိုက်များ၏ နောက်ဆုံးထုတ်ပြန်ချက်များကို မျှဝေမှုကို ရယူနိုင်ပါသည်',
	'ical_titre_js' => 'ဂျာဗားစခရစ် (ပရိုဂရမ်ဘာသာစကား)',
	'ical_titre_mailing' => 'စာပို့မှုစာရင်း',
	'ical_titre_rss' => 'ပူးတွဲချိတ်ဆက်သည့် ဖိုင်များ',
	'icone_activer_cookie' => 'ကွတ်ကီးကို ထားပါ',
	'icone_admin_plugin' => 'ထပ်မံချိတ်ဆက်မှုကို စီမံခန့်ခွဲပါ',
	'icone_afficher_auteurs' => 'စာရေးသူများကိုပြပါ',
	'icone_afficher_visiteurs' => 'ဝက်ဘ်ဆိုက်တွင်း ဝင်ရောက်ကြည့်ရှုသူများကို ပြပါ',
	'icone_arret_discussion' => 'ဤဆွေးနွေးမှုတွင် ပါဝင်မှုရပ်လိုက်ပါ',
	'icone_calendrier' => 'ပြက္ခဒိန်',
	'icone_creer_auteur' => 'စာရေးသူ အသစ်ဖန်တီး၍ ဤဆောင်းပါးနှင့် ချိတ်လိုက်ပါ',
	'icone_creer_rubrique_2' => 'ကဏ္ဍအသစ်တည်ဆောက်ပါ',
	'icone_modifier_article' => 'ဤဆောင်းပါးကို ပြန်လည်မွမ်းမံပါ',
	'icone_modifier_rubrique' => 'ဤကဏ္ဍကို ပြန်လည်မွမ်းမံပါ',
	'icone_retour' => 'နောက်သို့',
	'icone_retour_article' => 'ဆောင်းပါးသို့ပြန်သွားပါ',
	'icone_supprimer_cookie' => 'ကွတ်ကီးကို ဖျက်ပစ်ပါ',
	'icone_supprimer_rubrique' => 'ဤကဏ္ဍကို ဖျက်ပစ်ပါ',
	'icone_supprimer_signature' => 'ဤအမှတ်သားကို ဖျက်ပစ်ပါ',
	'icone_valider_signature' => 'ဤလက်မှတ်ကိုအတည်ပြုပါ',
	'image_administrer_rubrique' => 'ဤကဏ္ဍကို သင်စီမံနိုင်သည်',
	'impossible_modifier_login_auteur' => 'Impossible de modifier le login.', # MODIF
	'impossible_modifier_pass_auteur' => 'Impossible de modifier le mot de passe.', # MODIF
	'info_1_article' => '၁ ဆောင်းပါး',
	'info_activer_cookie' => 'ကိုယ်ပိုင်နေရာနှင့် အများသုံးဝက်ဘ်ဆိုက်ကြားသို့ အလွယ်တကူကူးနိုင်ရန် သင့်ကိုခွင့်ပြုထားသော  <b>ကြီးကြပ်သူကွတ်ကီး</b>တခုကို သင်အသက်သွင်းနိုင်သည်',
	'info_administrateur' => 'ကြီးကြပ်သူ', # MODIF
	'info_administrateur_1' => 'ကြီးကြပ်သူ', # MODIF
	'info_administrateur_2' => 'ဝက်ဆိုက်၏ (<i>သတိပေးချက်နှင့်အသုံးပြုပါ</i>)',
	'info_administrateur_site_01' => 'အကယ်၍သင်သည် ဝက်ဘ်ဆိုက် ကြီးကြပ်သူဖြစ်ပါက', # MODIF
	'info_administrateur_site_02' => 'ဤချိတ်ဆက်မှုပေါ် နှိပ်လိုက်',
	'info_administrateurs' => 'ဝက်ဘ်ဆိုက် ကြီးကြပ်သူများ', # MODIF
	'info_administrer_rubrique' => 'သင်သည်အခန်းကဏ္ဍကို စီမံခန့်ခွဲနိုင်သည်',
	'info_adresse' => 'လိပ်စာသို့',
	'info_adresse_url' => 'အများဆိုင်ရာ ဝက်ဘ်ဆိုက်လိပ်စာ',
	'info_aide_en_ligne' => 'SPIP အွန်လိုင်းအကူညီရယူရန်',
	'info_ajout_image' => 'ပုံရိပ်များကို ဆောင်းပါးများနှင့် ပူးတွဲထည့်သည့်အခါ SPIP မှ နမူနာပုံရိပ်ကို ဖန်တီးပေးပါမည်။',
	'info_ajouter_rubrique' => 'စာရေးသူကဏ္ဍကို စီမံရန်ထပ်ထည့်ပါ',
	'info_annonce_nouveautes' => 'နောက်ဆုံးကြေငြာချက်များ',
	'info_article' => 'ဆောင်းပါး',
	'info_article_2' => 'ဆောင်းပါးများ',
	'info_article_a_paraitre' => 'ဆောင်းပါးများထုတ်ဝေရမည့် နောက်ဆုံးရက်စွဲ',
	'info_articles_02' => 'ဆောင်းပါးများ',
	'info_articles_2' => 'ဆောင်းပါးများ',
	'info_articles_auteur' => 'ဤစာရေးသူ၏ ဆောင်းပါးများ',
	'info_articles_trouves' => 'ဆောင်းပါးများတွေ့သည်',
	'info_attente_validation' => 'သင့်ဆောင်းပါးများကို ပယ်ရန်အတည်ပြုခြင်း',
	'info_aujourdhui' => 'ဒီနေ့',
	'info_auteurs' => 'စာရေးသူများ',
	'info_auteurs_par_tri' => 'စာရေးသူများ@partri@',
	'info_auteurs_trouves' => 'စာရေးသူများကို တွေ့သည်',
	'info_authentification_externe' => 'ပြင်ပအတည်ပြုချက်',
	'info_avertissement' => 'သတိပေးချက်',
	'info_base_installee' => 'သင့်အချက်လက် သိုလှောင်မှု တည်ဆောက်ပုံကို ထည့်သွင်းပြီးဖြစ်သည်',
	'info_chapeau' => 'စာရေးခုံ',
	'info_chapeau_2' => 'မိတ်ဆက်ခြင်း',
	'info_chemin_acces_1' => 'ရွေးချယ်ရန်များ <b>ဖိုင်လမ်းညွှန်ထဲရှိ ဆက်သွယ်ရန်လမ်းကြောင်း</b>',
	'info_chemin_acces_2' => 'အခုမှစပြီး ဖိုင်တွဲသို့ ဆက်သွယ်ရန် လိပ်စာလမ်းကြောင်းကို တပ်ဆင်ရမည်။ ဤလိပ်စာသည် သုံးစွဲသူ သိမ်းဆည်းထားသော ကိုယ်ရေးရာဇဝင် ဖိုင်များကို ရယူရန် မရှိမဖြစ်လိုအပ်ပါသည်။', # MODIF
	'info_chemin_acces_annuaire' => 'ရွေးချယ်ရန်များ <b>ဖိုင်လမ်းညွှန်ထဲရှိ ဆက်သွယ်ရန်လမ်းကြောင်း</b>',
	'info_choix_base' => 'တတိယအဆင့်',
	'info_classement_1' => ' out of @liste@',
	'info_classement_2' => ' out of @liste@',
	'info_code_acces' => 'သင့်ကိုယ်ပိုင်ကုတ်ကို မမေ့ပါနှင့်',
	'info_config_suivi' => 'ဤလိပ်စာသည် အများစာပို့လိပ်စာနှင့် ပတ်သက်မှုရှိလျှင် ဆိုက်တွင်ပါဝင်​သူများ မှတ်ပုံတင်နိုင်မည့် နေရာကို သိသာရန် လိပ်စာကိုဖော်ပြနိုင်သည်။ ဝက်ဘ်ဆိုက်မှတဆင့် မှတ်ပုံတင်နိုင်ရန် လိပ်စာသည် ဝက်ဘ်လိပ်စာဖြစ်သင့်သည်။ သို့မဟုတ် အကြောင်းအရာ သတ်မှတ်ဖော်ပြထားပြီးသား အီးမေးလ်လိပ်စာဖြစ်သင့်သည်<tt>@adresse_suivi@?subject=subscribe</tt>)',
	'info_config_suivi_explication' => 'အများစာပို့လိပ်စာကို သင်လည်း ရယူပါဝင်နိုင်သည်။ ထုတ်ဝေရန် တင်သွင်းသည့် ဆောင်းပါးနှင့် သတင်းများ၏ အကြောင်းကြားချက်များကို ​အီးမေးလ်မှတဆင့် အလိုအလျှောက်​ ရောက်လာပါလိမ့်မည်',
	'info_confirmer_passe' => 'စကားဝှက်အသစ်ကို အတည်ပြုပါ',
	'info_connexion_base' => 'ဒုတိယအဆင့် <b>သတင်းအချက်လက် သိုလှောင်မှုကို ဆက်သွယ်ရန်</b>',
	'info_connexion_ldap_ok' => 'LDAP ချိတ်ဆက်မှုအောင်မြင်သည်၊</b><p> သင်နောက်တဆင့်ဆက်သွားနိုင်သည်</p>', # MODIF
	'info_connexion_mysql' => 'ပထမအဆင့် <b>သင့် MySQL ဆက်သွယ်မှု</b>',
	'info_connexion_ok' => 'ဆက်သွယ်မှုအောင်မြင်သည်',
	'info_contact' => 'ဆက်သွယ်သည်',
	'info_contenu_articles' => 'ဆောင်းပါးများ အညွှန်း',
	'info_creation_paragraphe' => '(စာပိုဒ်များ တည်ဆောက်ရန် ဗလာလိုင်းများကို ချန်ခဲ့ပါ)', # MODIF
	'info_creation_rubrique' => 'ဆောင်းပါးများကို ရေး၍မရမီ<br /> အခန်းကဏ္ဍ အနည်းဆုံးတခုကို တည်ဆောက်ပါ<br />',
	'info_creation_tables' => 'စတုတ္ထအဆင့် <b>အချက်လက် သိုလှောင်မှုဇယား အသစ်တည်ဆောကရန်</b>',
	'info_creer_base' => 'အချက်လက် သိုလှောင်မှုအသစ်<b>တည်ဆောက်ပါ</b>',
	'info_dans_rubrique' => 'ကဏ္ဍထဲတွင်',
	'info_date_publication_anterieure' => 'အရင်ထုတ်ဝေခဲ့သည့် ရက်စွဲ',
	'info_date_referencement' => 'ဤဆိုက်ကို ကိုးကားသည့်ရက်စွဲ',
	'info_derniere_etape' => 'နောက်ဆုံးအဆင့် <b>လုပ်ပြီးပြီ',
	'info_descriptif' => 'ဖော်ပြချက်',
	'info_discussion_cours' => 'ဆွေးနွေးနေဆဲ',
	'info_ecrire_article' => 'ဆောင်းပါးများမရေးမီ အနည်းဆုံး အခန်းကဏ္ဍတစ်ခုကို အရင်ဖန်တီးပါ',
	'info_email_envoi' => 'ပေးပို့သူ၏လိပ်စာ (ဖြစ်နိုင်လျှင်)',
	'info_email_envoi_txt' => 'စာပို့သူ၏ အီးမေးလ်လိပ်စာကိုထည့်ပြီး စာပို့နေစဉ်တွင် အသုံးပြုပါ၊ (သတ်မှတ်ချက်- လက်ခံသူလိပ်စာကို ပေးပို့သူလိပ်စာအဖြစ်သုံးသည်)',
	'info_email_webmestre' => 'ဝက်ဘ်ဆိုက်အုပ်ချုပ်သူ၏ အီးမေးလ်လိပ်စာ', # MODIF
	'info_envoi_email_automatique' => 'အလိုအလျောက်စာပို့ခြင်း',
	'info_envoyer_maintenant' => 'အခုပို့လိုက်ပါ',
	'info_etape_suivante' => 'နောက်တဆင့်သို့သွားပါ',
	'info_etape_suivante_1' => 'နောက်တဆင့်သို့ ရွေ့နိုင်သည်',
	'info_etape_suivante_2' => 'နောက်တဆင့်သို့ ရွေ့နိုင်သည်',
	'info_exportation_base' => 'အချက်အလက် သိုလှောင်မှုကို @archive@သို့ပို့ပါ',
	'info_facilite_suivi_activite' => 'To facilitate the follow-up of the site’s editorial;  activities, SPIP can send notification by email, to an editor’s mailing list for instance, of publication requests and article validations.', # MODIF
	'info_fichiers_authent' => 'ဖိုင်\\".htpasswd\\"ကို အတည်ပြုပါ',
	'info_forums_abo_invites' => 'သင့်ဝက်ဘ်ဆိုက် ဖိုရမ်မှာ အခမဲ့ဖြစ်သည်၊ ဝင်ရောက်ကြည့်ရှုသူများက အများသုံး ဝက်ဘ်ဆိုက်ပေါ်တွင် မှတ်ပုံတင်လိမ့်မည်', # MODIF
	'info_gauche_admin_tech' => '<b>ဝက်ဘ်ဆိုက်ကြီးကြပ်သူသာ ဤစာမျက်နှာသို့ဝင်နိုင်သည်၊</b><p> သည်ဟာက လုပ်ငန်းများစွာကို ထိန်းသိမ်းရန်အတွက် အထောက်ကူပြုသည်၊  အချို့က ဝက်ဘ်ဆိုက်ပေါ်တွင် လိုအပ်သော FTP ဆက်သွယ်မှုကို လုပ်ဆောင်စေနိုင်သည်</p>', # MODIF
	'info_gauche_auteurs' => 'ဝက်ဘ်ဆိုက်အားလုံး၏ စာရေးသူများကို သည်မှာမြင်နိုင်သည်၊ ၎င်းတို့တခုစီ၏ အနေအထားများကို ရောင်စုံပုံဖြင့် ဖော်ပြထားသည် (ဝက်ဘ်ဆိုက်ကြီးကြပ်သူ = စိမ်းရောင်။ စာတည်း = အဝါရောင်)', # MODIF
	'info_gauche_auteurs_exterieurs' => 'ဝက်ဘ်ဆိုက်နှင့် ဆက်သွယ်မှုမရှိသော ပြင်ပစာရေးသူများကို အပြာရောင်ဖြင့်ဖော်ပြသည်၊ အမှိုက်ပုံးထဲ ထည့်၍ ၎င်းစာရေးသူများကို ဖျက်ပစ်ပါ', # MODIF
	'info_gauche_messagerie' => 'စာပေးပို့ခြင်းက စာတည်းများကြားတွင် စာများကိုကာကွယ်ရန် စာအပြန်အလှန်ဖလှယ်ခြင်း (သင့်ကိုယ်ပိုင်သုံးရန်) သို့မဟုတ် ကိုယ်ပိုင်နေရာ၏ ကနဦးစာမျက်နှာတွင် ကြေငြာချက်များကို ဖော်ပြရန်ခွင့်ပြူသည် (အကယ်၍သင်သည် ကြီးကြပ်သူဖြစ်ခဲ့လျှင်ပေါ့)', # MODIF
	'info_gauche_statistiques_referers' => 'ဤစာမျက်နှာတွင်  <i>အကိုးကားယူသည့်နေရာများ</i> စာရင်းကို ဖော်ပြမည်။ ၄င်းသည် သင့်ကိုယ်ပိုင်ဝက်ဘ်ဆိုက်သို့ ချိတ်ဆက်ထားသော ဝက်ဘ်​ဆိုက်များဖြစ်ပြီး မနေ့နှင့် ဒီနေ့အတွက်တရက်ချင်းစာရင်းဖြစ်သည်',
	'info_gauche_visiteurs_enregistres' => 'ဤဝက်ဆိုက်၏ အများသုံးနေရာ အတွင်းဝင်ရောက်ကြည့်ရှုသူများမှတ်ပုံတင်ကို သင်မြင်မည်(ဖိုရမ်များ ခွင့်ပြုချက်ဖြင့်)',
	'info_generation_miniatures_images' => 'ရုပ်ပုံများကို မြင်သာရန်ဖန်တီးနေသည်',
	'info_hebergeur_desactiver_envoi_email' => 'အချို့ပင်မဆာဗာများသည် ၎င်းတို့ဆာဗာပေါ်တွင် အလိုလျောက် အီးမေးလ်မပို့နိုင်ပါ၊ ဤသို့ဖြစ်ပါက အေက်ပါ SPIPသဏ္ဍန်များကိုလည်း အကောင်ထည်မဖော်နိုင်ပါ',
	'info_hier' => 'မနေ့က',
	'info_identification_publique' => 'အများသုံး အမှတ်အသား',
	'info_image_process' => 'ဆက်သွယ်ထားသောပုံပေါ်တွင်နှိပ်လိုက်သောအခါ ရုပ်ပုံမြင်နိုင်ရန်အတွက် အကောင်းဆုံးဖန်တီးမှုနည်းလမ်းကိုရွေးပါ',
	'info_image_process2' => '<b>N.B.</b> <i>ပုံရိပ်တခုမှ မတွေ့ရလျှင်၊ သင့်ဆာဗာသည် အဲဒီအတွက် တပ်ဆင်ထားခြင်း မရှိလို့ဖြစ်ပါမည်။ ဤလုပ်ဆောင်မှုကို သင်အလိုရှိတယ်ဆိုရင် ဝက်ဘ်ဝန်ဆောင်မှုကို ဆက်သွယ်ပြီးတော့ «GD» သို့မဟုတ် «Imagick» extensions ကို ထည့်သွင်းပေးပါရန် တောင်းဆိုပါ။</i>', # MODIF
	'info_images_auto' => 'ပုံများကို အလိုအလျောက်တွက်ချက်သည်',
	'info_informations_personnelles' => 'ပဉ္စမအဆင့် <b>ကိုယ်ရေးကိုယ်တာအချက်လက်</b>',
	'info_inscription_automatique' => 'စာတည်များကို ​အလိုအလျေက်မှတ်ပုံတင်ခြင်း', # MODIF
	'info_jeu_caractere' => 'ဝက်ဘ်ဆိုက်သွင်ပြင်လက္ခဏာစု',
	'info_jours' => 'ရက်များ',
	'info_laisser_champs_vides' => '(ဤဖိုင်ကို ဗလာဖြစ်အောင်လုပ်ပါ)',
	'info_langues' => 'ဝက်ဘ်ဆိုက်ဘာသာစကားများ',
	'info_ldap_ok' => 'LDAP မှန်ကန်မှု စစ်ဆေးခြင်းကို စတင်ထည့်သွင်းနေသည်',
	'info_lien_hypertexte' => 'ဆက်နွယ်မှု',
	'info_liste_redacteurs_connectes' => 'ဆက်သွယ်သည့် စာတည်းစာရင်းများ', # MODIF
	'info_login_existant' => 'ဝင်ရောက်မှုကို ပိတ်ပင်ထားပြီး',
	'info_login_trop_court' => 'ဝင်ရောက်မှုတိုလွန်းသည်',
	'info_maximum' => 'အများဆုံး',
	'info_meme_rubrique' => 'တစ်ကဏ္ဍထဲတွင်',
	'info_message_en_redaction' => 'သင့်​စာစောင်ကို ပြုလုပ်နေဆဲ',
	'info_message_technique' => 'နည်းပညာဆိုင်ရာ မှာကြားချက်',
	'info_messagerie_interne' => 'အတွင်းပိုင်းစာစောင်',
	'info_mise_a_niveau_base' => 'MySQL အချက်လက်သိုလှောင်ခြင်း မြှင့်တင်မှု',
	'info_mise_a_niveau_base_2' => '{{သတိပေးချက်!}} ဤဆိုက်တွင် ထည့်သွင်းထားပြီးသော SPIP မူကွဲထက် ဟောင်းသော မူကွဲကို သင်ထည့်သွင်းမိပြီ။ သင့်သိုလှောင်မှု အန္တရယ်ရှိပြီ သို့ ပျက်ဆီးနှင့်ပြီ။ သင့်ဆိုက်သည်လည်း ကောင်းမွန်စွာနှင့် အလုပ်လုပ်တော့မည် မဟုတ်ပါ။ <br />{{သင့်လျော်သော SPIP ဖိုင်များကို ပြန်လည် ထည့်သွင်းပါ}}',
	'info_modifier_rubrique' => 'ကဏ္ဍကို ပြုပြင်မွမ်းမံပါ',
	'info_modifier_titre' => '@titre@ကို ပြုးပြင်မွမ်းမံပါ',
	'info_mon_site_spip' => 'SPIP ဆိုက်',
	'info_moyenne' => 'ပျမ်းမျှ',
	'info_multi_cet_article' => 'သည်ဆောင်းပါး ဘာသာစကား',
	'info_multi_langues_choisies' => 'အောက်ဖော်ပြပါ ဘာသာစကားများကို စားတည်းများ​ ​ရွေးချယ်နိုင်အောင် ပြုလုပ်ပါ။ သင့်ဆိုက်တွင် အသုံးပြုနေသော ဘာသာစကားများကို ပြန်လည် ပိတ်ပင်၍ မရနိုင်တော့ပါ။', # MODIF
	'info_multi_secteurs' => 'ဆိုက်၏ ပထမဆုံး စာမျက်နှာတွင်တွင် အခန်းကဏ္ဍများကိုသာ မြင်စေလိုပါသလား',
	'info_nom' => 'အမည်',
	'info_nom_destinataire' => 'ပါဝင်သူအမည်',
	'info_nom_site' => 'သင့်ဝက်ဘ်ဆိုက်နာမည်',
	'info_nombre_articles' => '@nb_articles@ ဆောင်းပါးများ',
	'info_nombre_rubriques' => '@nb_rubriques@အပိုင်းကဏ္ဍများ',
	'info_nombre_sites' => '@nb_sites@ဝက်ဘ်ဆိုက်များ',
	'info_non_deplacer' => 'မရွှေ့ပါနှင့်',
	'info_non_envoi_annonce_dernieres_nouveautes' => 'SPIP သည် ဝက်ဘ်ဆိုက်၏ နောက်ဆုံးကြေငြာချက်သတင်းများကို မှန်မှန်ပို့ပေးနိုင်ပါသည် (လက်ရှိထုတ်ဝေသော သတင်းနှင့် ဆောင်းပါးများ).',
	'info_non_envoi_liste_nouveautes' => 'နောက်ဆုံးရ သတင်းစာရင်းကို မပို့ပါနှင့်',
	'info_non_modifiable' => 'ပြန်လည်ပြုပြင်မွမ်းမံ၍မရပါ',
	'info_non_suppression_mot_cle' => 'သည်သော့ချက်စကားလုံးကို မဖျက်ပစ်ချင်ပါ',
	'info_notes' => 'အောက်ခြေမှတ်စု',
	'info_nouvel_article' => 'ဆောင်းပါးအသစ်',
	'info_nouvelle_traduction' => 'ဘာသာပြန်အသစ်',
	'info_numero_article' => 'ဆောင်းပါးနံပါတ်',
	'info_obligatoire_02' => '[လိုအပ်ပါသည်]', # MODIF
	'info_option_accepter_visiteurs' => 'ဝင်ရောက်လည်ပတ်သူများအား အ​များသုံးဝက်ဘ်ဆိုက်မှ မှတ်ပုံတင်ရန်ခွင့်ပြုသည်', # MODIF
	'info_option_ne_pas_accepter_visiteurs' => 'ဝင်ရောက်လည်ပတ်သူမှတ်ပုံတင်ခြင်းကို ငြင်းဆိုသည်', # MODIF
	'info_options_avancees' => 'အဆင့်မြှင့်ရွေးချယ်မှုများ',
	'info_ou' => 'သို့မဟုတ်',
	'info_page_interdite' => 'တားမြစ်စာမျက်နှာ',
	'info_par_nom' => 'အမည်အလိုက်',
	'info_par_nombre_article' => 'ဆောင်းပါးများ အမှတ်စဉ်အလိုက်',
	'info_par_statut' => 'ရောက်နေသည့် အခြေနေအလိုက်',
	'info_par_tri' => '’(@tri@ဖြင့်)’',
	'info_passe_trop_court' => 'စကားဝှက်တိုလွန်သည်',
	'info_passes_identiques' => 'စကားဝှက်နှစ်ခု မတူညီပါ',
	'info_plus_cinq_car' => 'အက္ခရာ ငါး လုံးထက်ပို၍',
	'info_plus_cinq_car_2' => '(အက္ခရာ ငါး လုံးထက်ပို၍)',
	'info_plus_trois_car' => '(အက္ခရာ သုံး လုံးထက်ပို၍)',
	'info_popularite' => 'ထင်ပေါ်ကျော်ကြားမှု - @popularite@; ဝင်ရောက်လည်ပတ်သူများ @visites@',
	'info_post_scriptum' => 'ပို့စခရစ် (ပရိုဂရမ်ဘာသာစကား)',
	'info_post_scriptum_2' => 'ပို့စခရစ် (ပရိုဂရမ်ဘာသာစကား)',
	'info_pour' => 'အတွက်',
	'info_preview_texte' => 'ဤဆိုက်ပေါ်ရှိ ဆောင်းပါးများ၊ သတင်းများ အားလုံးကို ကြည့်ရှုနိုင်ပါသည် (ထုတ်ဝေရန် တင်သွင်းပြီး၊ ထုတ်ဝေပြီးသား ဆိုရင်)။ ဤသို့ကြည့်ရှုခွင့်ကို စီမံကြီးကြပ်သူများ အ​တွက်သီးသန့် ဖြစ်စေလိုပါသလား (သို့) စာရေးသူများ အားလုံးကို ခွင့်ပြုလိုပါသလား (သို့) လုံးဝဥတုံ ပိတ်ထားချင်သလား?', # MODIF
	'info_procedez_par_etape' => 'အဆင့်လိုက်စတင်လုပ်ဆောင်ပါ',
	'info_procedure_maj_version' => 'အဆင့်မြှင့်တင် လုပ်ဆောင်မှုသည် SPIP၏ သိုလှောင်မှု မူကွဲအသစ်နှင့် ကိုက်ညီရန် လိုအပ်သည်',
	'info_proxy_ok' => 'proxy စမ်းသပ်မှုအောင်မြင်သည်',
	'info_ps' => 'စာကြွင်း',
	'info_publier' => 'ထုတ်ဝေပါ',
	'info_publies' => 'သင့်ဆောင်းပါးများကို အွန်လိုင်​တွင်ထုတ်လွင့်သည်',
	'info_question_accepter_visiteurs' => 'သင့်ဝက်ဘ်ဆိုက်သို့ ဝင်ရောက်လည်ပတ်သူများကို ကိုယ်ပိုင်နေရာသို့ ဝင်စရာမလိုဘဲ မှတ်ပုံတင်ရန်ခွင့်ပြုထားပါက အောက်ပါရွေးချယ်မှုများကို ပြူလုပ်ပါ', # MODIF
	'info_question_inscription_nouveaux_redacteurs' => 'စာတည်းအသစ်များ မှတ်ပုံတင်ခွင့်ကို အများဆိုင်နေရာမှ လုပ်ဆောင်ခွင့် ပေးလိုပါသလား? သင်ခွင့်ပြုမည်ဆိုလျှင် လာလည်သူများသည်လည်း အလိုအလျှောက် ဖောင်ကိုအသုံးပြု၍ မှတ်ပုံတင်နိုင်မည်ဖြစ်သည်။ သူတို့ဖန်တီးထားသော ဆောင်းပါးများကို တိုက်ရိုက်မွမ်းမံ နိုင်မည်ဖြစ်သဖြင့် နှစ်သက်ပါလိမ့်မည်။<blockquote><i> မှတ်ပုံတင်ခြင်းလုပ်ဆောင်နေစဉ် ကိုယ်ပိုင်ကန့်သတ်နေရာသို့ ဝင်ရောက်နိုင်ရန် လိုအပ်သော အချက်အလက်များကို အလိုအလျှောက်အီးမေးလ်မှ ရောက်လာပါလိမ့်မည်။ တချို့သော ဝက်ဘ်ဝန်ဆောင်မှုလုပ်ငန်းများသည် ဤအလိုအလျှောက် စာပို့ခြင်းကို လက်မခံကြပေ၊ ဤသို့ဖြစ်နေလျှင် ဤစာပို့ခြင်းသည် အ​ဆင်ပြေမည်မဟုတ်ပါ။', # MODIF
	'info_racine_site' => 'ဝက်ဘ်ဆိုက် ပင်မဇစ်မြစ်',
	'info_recharger_page' => 'မိနစ်အနည်းငယ်အတွင်း ဤစာမျက်နှာကို ပြန်ဖွင့်ပါ',
	'info_recherche_auteur_zero' => ' \\"@cherche_auteur@\\"အတွက် ရလာဒ်မရှိပါ',
	'info_recommencer' => 'ပြန်ကြိုးစားပါ',
	'info_redacteur_1' => 'Rédacteur',
	'info_redacteur_2' => '(<i>ထင်မြင်အကြံပြုခြင်း</i>)ကိုယ်ပိုင်နေရာသို့ရောက်နိုင်သည်',
	'info_redacteurs' => 'စာတည်းများ',
	'info_redaction_en_cours' => 'တည်းဖြတ်နေဆဲ',
	'info_redirection' => 'လမ်းကြောင်းလွဲခြင်း',
	'info_refuses' => 'သင့်ဆောင်းပါးကို ငြင်းပယ်သည်',
	'info_reglage_ldap' => 'ရွေးချယ်ရန်များ - <b>LDAP တင်သွင်းမှုကို ညှိနေသည်</b>',
	'info_renvoi_article' => '<b>လမ်းကြောင်းလွဲခြင်း</b> ဤဆောင်ပါးသည် () သို့လမ်းလွဲနေသည်',
	'info_reserve_admin' => 'ကြီးကြပ်သူကသာ ဤလိပ်စာများကို ပြုပြင်မွမ်းမံခွင့်ရှိသည်', # MODIF
	'info_restreindre_rubrique' => 'ကဏ္ဍများ စီမံခန့်ခွဲမှု ကန့်သတ်ချက်',
	'info_resultat_recherche' => 'ရှာဖွေမှုရလာဒ်များ',
	'info_rubriques' => 'ကဏ္ဍများ',
	'info_rubriques_02' => 'ကဏ္ဍများ',
	'info_rubriques_trouvees' => 'အပိုင်းကဏ္ဍများကို တွေ့ရသည်',
	'info_sans_titre' => 'ခေါင်းစဉ်မရှိ',
	'info_selection_chemin_acces' => ' အညွှန်းရှိ အောက်ပါအသုံးပြုခွင့်ရအပိုင်းကို <b>ရွေးပါ</b>',
	'info_signatures' => 'အမှတ်အသား',
	'info_site' => 'ဝက်ဘ်ဆိုက်',
	'info_site_2' => 'ဝက်ဘ်ဆိုက်',
	'info_site_min' => 'ဝက်ဘ်ဆိုက်',
	'info_site_reference_2' => 'ကိုးကားဝက်ဘ်ဆိုက်',
	'info_site_web' => 'ဝက်ဘ်ဆိုက်', # MODIF
	'info_sites' => 'ဝက်ဘ်ဆိုက်များ',
	'info_sites_lies_mot' => 'ဤသော့ချက်စကားလုံးနှင့် သင့်လျော်သော ကိုးကားဝက်ဘ်ဆိုက်များ',
	'info_sites_proxy' => 'ကြားခံဆာဗာကို အသုံးပြုနေသည်',
	'info_sites_trouves' => 'ဝက်ဘ်ဆိုက်များကို တွေ့သည်',
	'info_sous_titre' => 'ခေါင်းစဉ်ခွဲ',
	'info_statut_administrateur' => 'ကြီးကြပ်သူ', # MODIF
	'info_statut_auteur' => 'ဤစာရေးသူ၏ အခြေနေ', # MODIF
	'info_statut_auteur_a_confirmer' => 'အတည်ပြုရန် မှတ်တမ်းတင်ခြင်း',
	'info_statut_auteur_autre' => 'အခြားအ​ခြေနေ',
	'info_statut_redacteur' => 'စာတည်း',
	'info_statut_utilisateurs_1' => 'တင်သွင်ထားသောအသုံးပြုသူများဿ သတ်မှတ်မထားသောအခြေနေ', # MODIF
	'info_statut_utilisateurs_2' => 'LDAP လမ်းညွှန်ထဲသို့ ပထမဆုံးအကြိမ် တင်ဆက်သော ပုဂ္ဂိုလ်၏ နေအထားကို ရွေးချယ်ပါ။ နောက်နောင်မှာလည်း အမှုစီတိုင်းပေါ်မူတည်ပြီး စာရေးသူ တယေက်ချင်းစီအတွက် ပြန်လည်မွမ်းမံနိုင်ပါသည်။', # MODIF
	'info_suivi_activite' => 'စာတည်းလုပ်ငန်း နောက်ဆက်တွဲ',
	'info_surtitre' => 'ထိပ်စည်းခေါင်းစဉ်',
	'info_syndication_integrale_1' => 'သင့်ဝက်ဘ်ဆိုက်တွင် အကျိုးတူဖိုင် (ကြည့်ရန် <a href=\\"@url@\\">@titre@</a>) ကို အခမဲ့ ကြည့်ရှုခွင့်ပေးသည်',
	'info_syndication_integrale_2' => 'ဆောင်းပါးတခုလုံး (သို့) အက္ခရာအနည်းငယ်သာပါတဲ့ နမူနာကိုသာ ပို့ချင်ပါသလား',
	'info_taille_maximale_vignette' => 'စစ်စတမ်ဖြင့် စာရွက်အကွာအဝေးအကြီးဆုံးကို ပြန်လည်ပြုလုပ်ပါ',
	'info_terminer_installation' => 'စတင်ထည့်သွင်းခြင်းစံကို ယခုအဆုံးသတ်နိုင်ပြီ',
	'info_texte' => 'စာသား',
	'info_texte_explicatif' => 'စာသားရှင်းလင်းချက်',
	'info_texte_long' => '(စာသားကရှည်သည်။ ၄င်းတို့ကို အတည်ပြုပြီးလျှင် ​အဆင်ပြေသလို စီမံဖော်ပြပေးပါလိမ့်မည်)',
	'info_texte_message' => 'သင့် မှာကြားချက်ရှိ စာသား', # MODIF
	'info_texte_message_02' => 'မှာကြားချက်ရှိ စာသား',
	'info_titre' => 'ခေါင်းစဉ်',
	'info_total' => 'ပေါင်း',
	'info_tous_articles_en_redaction' => 'ဆောင်းပါးအားလုံးကို ပြုလုပ်ဆဲ',
	'info_tous_articles_presents' => 'ဤကဏ္ဍတွင် ထုတ်ဝေထားသော ဆောင်းပါးအားလုံး',
	'info_tous_les' => 'အမြဲ',
	'info_tout_site' => 'လက်ရှိဝက်ဘ်ဆိုက်',
	'info_tout_site2' => 'ဤဆောင်းပါးကို ဒီဘာသာသို့ ဘာသာမပြန်ရသေးပါ',
	'info_tout_site3' => 'ဤဆောင်းပါးကို ဒီဘာသာသို့ ဘာသာပြန်ပြီးဖြစ် သို့သော် ထပ်မံဖြည့်စွက်ခြင်း ရှိပါသဖြင့် ဘာသာပြန်ခြင်းကိုလည်း ပြန်လည်မွမ်းမံရန် လိုအပ်ပါသည်',
	'info_tout_site4' => 'ဤဆောင်းပါးကို ဒီဘာသာသို့ ဘာသာပြန်ပြီးဖြစ်၍ ဘာသာပြန်ကိုလည်း ပြုပြင်မွမ်းမံရန် လိုအပ်သည်',
	'info_tout_site5' => 'မူရင်းဆောင်းပါး',
	'info_tout_site6' => '<b>သတိပေးချက်</b> မူရင်းဆောင်းပါးများကိုသာ ဖော်ပြပါသည်။ ဘာသာပြန်များသည် မူရင်းနှင့်ရောထွေးနေသည်၊ ၄င်းတို့၏ အခြေနေကို ကာလာက ကိုယ်စားပြုပါသည်',
	'info_travail_colaboratif' => 'ဆောင်းပါးများတွင် အလုပ်နှစ်မျိုးလုပ်သည်',
	'info_un_article' => 'ဆောင်းပါးတပုဒ်',
	'info_un_site' => 'ဝက်ဘ်ဆိုက်တခု,',
	'info_une_rubrique' => 'ကဏ္ဍတခု',
	'info_une_rubrique_02' => '၁ အခန်းကဏ္ဍ',
	'info_url' => 'ဝက်ဘ်ဆိုက်လိပ်စာ',
	'info_urlref' => 'ဆက်နွယ်မှု',
	'info_utilisation_spip' => 'SPIP ကို အသုံးပြုရန် အဆင်သင့်ဖြစ်ပြီ',
	'info_visites_par_mois' => 'လစဉ်​ဖော်ပြချက်',
	'info_visiteur_1' => 'ဝက်ဘ်ဆိုက်သို့ ဝင်ရောက်လာလည်သူ',
	'info_visiteur_2' => 'အများသုံးဝက်ဘ်ဆိုက်၏',
	'info_visiteurs' => 'ဝက်ဘ်ဆိုက်ကို ဝင်ရောက် အလည်လာသူများ',
	'info_visiteurs_02' => 'အများသုံးဝက်ဘ်ဆိုက်ကို ဝင်ရောက်လည်ပတ်သူများ',
	'install_echec_annonce' => 'ဤစတင်ထည့်သွင်းမှု လုပ်၍မရပါ (သို့) လုပ်ဆောင်မှုမရှိသော ဝက်ဘ်ဆိုက် ရလာဒ်ကိုသာရမည်',
	'install_extension_mbstring' => 'SPIP သည် () နှင့်အတူ အလုပ်မလုပ်ပါ',
	'install_extension_php_obligatoire' => 'SPIP တွင် php တိုးချဲ့ရန်လိုသည်',
	'install_php_version' => 'PHP မူကွဲ @Version@သည် ဟောင်းလွန်းပြီဖြစ်သည် (အနည်းဆုံး = @minimum@)',
	'install_select_langue' => 'ဘာသာစကားကိုရွေးချယ်ပါ၊ ထို့နောက် စတင်ထည့်သွင်းခြင်း လုပ်ထုံးလုပ်နည်းများကို စတင်ရန်အတွက် \\"နောက်တခု\\" စာလုံးကိုနှိပ်ပါ',
	'intem_redacteur' => 'စာတည်း',
	'item_accepter_inscriptions' => 'မှတ်ပုံတင်ခြင်းများကို ခွင့်ပြုသည်',
	'item_activer_messages_avertissement' => 'သတိပေးတားမြစ်စာများကို အသက်သွင်းပါ',
	'item_administrateur_2' => 'ကြီးကြပ်သူများ', # MODIF
	'item_afficher_calendrier' => 'ပြက္ခဒိန်တွင် ဖော်ပြပါ',
	'item_autoriser_syndication_integrale' => 'ပူးတွဲချိတ်ဆက်မှုထဲတွင် ဆောင်းပါးအားလုံးပါဝင်သည်',
	'item_choix_administrateurs' => 'ကြီးကြပ်သူများ', # MODIF
	'item_choix_generation_miniature' => 'ပုံများကို အလိုအလျောက် မြင်နိုင်ရန် ပြုလုပ်ပါ',
	'item_choix_non_generation_miniature' => 'ပုံများကို မြင်နိုင်အောင်မလုပ်ပါ',
	'item_choix_redacteurs' => 'စာတည်းများ',
	'item_choix_visiteurs' => 'အများသုံး ဝက်ဘ်ဆိုက်သို့ ဝင်ရောက်လည်ပတ်သူများ',
	'item_creer_fichiers_authent' => '.htpasswd ဖိုင်များကို တည်ဆောက်ပါ',
	'item_login' => 'ဝင်ရောက်ရန်',
	'item_mots_cles_association_articles' => 'ဆောင်းပါးများ',
	'item_mots_cles_association_rubriques' => 'အခန်းကဏ္ဍများ',
	'item_mots_cles_association_sites' => 'ကိုးကား (သို့) အမျိုးအစားတူ ဝက်ဘ်ဆိုက်များ',
	'item_non' => 'မဟုတ်',
	'item_non_accepter_inscriptions' => 'မှတ်ပုံတင်ခြင်းများကို ခွင့်မပြုပါ',
	'item_non_activer_messages_avertissement' => 'သတိပေးတားမြစ်ချက်စာမရှိပါ',
	'item_non_afficher_calendrier' => 'ပြက္ခဒိန်တွင် မဖော်ပြပါနှင့်',
	'item_non_autoriser_syndication_integrale' => 'နမူနာကိုသာပို့ပါ',
	'item_non_creer_fichiers_authent' => 'ဤဖိုင်များကို မတည်ဆောက်ပါနှင့်',
	'item_non_publier_articles' => 'ဆောင်းပါးများ ထုတ်ဝေရမည့် ရက်စွဲမတိုင်မီ မထုတ်ဝေပါနှင့်',
	'item_nouvel_auteur' => 'စာရေးသူအသစ်',
	'item_nouvelle_rubrique' => 'ကဏ္ဍအသစ်',
	'item_oui' => 'ဟုတ်ကဲ့',
	'item_publier_articles' => 'ဆောင်းပါးများကို ၎င်းတို့ရက်စွဲနှင့် မဟုတ်ဘဲထုတ်​ဝေပါ',
	'item_reponse_article' => 'ဆောင်းပါးကို စာပြန်ရန်',
	'item_visiteur' => 'ဝက်ဘ်ဆိုက်သို့လာလည်သူ',

	// J
	'jour_non_connu_nc' => 'အမည်မသိ',

	// L
	'lien_ajouter_auteur' => 'ဤစာရေးသူကို ထပ်ထည့်ပါ',
	'lien_email' => 'လျှပ်စစ်စာပို့စနစ်',
	'lien_nom_site' => 'ဝက်ဘ်ဆိုက်အမည်',
	'lien_retirer_auteur' => 'စာရေးသူကို ဖျေက်ပစ်ပါ',
	'lien_site' => 'ဝက်ဘ်ဆိုက်',
	'lien_tout_deplier' => 'အကုန်ချဲ့ပါ',
	'lien_tout_replier' => 'အားလုံးကို ခေါက်သိမ်းပါ',
	'lien_tout_supprimer' => 'အကုန်ဖျက်ပစ်ပါ',
	'lien_trier_nom' => 'နာမည်အလိုက်စီပါ',
	'lien_trier_nombre_articles' => 'ဆောင်းပါးများအလိုက်စီပါ',
	'lien_trier_statut' => 'အဆင့်များအလိုက်စီပါ',
	'lien_voir_en_ligne' => 'အွန်လိုင်းတွင်ကြည့်ပါ',
	'logo_article' => 'ဆောင်းပါးများ၏လိုဂို', # MODIF
	'logo_auteur' => 'စာရေးသူများ၏လိုဂို', # MODIF
	'logo_rubrique' => 'အခန်းကဏ္ဍ၏လိုဂို', # MODIF
	'logo_site' => 'ဤဝက်ဘ်ဆိုက်၏ လိုဂို', # MODIF
	'logo_standard_rubrique' => 'အခန်းကဏ္ဍများအတွက် ဘုံလိုဂို', # MODIF

	// M
	'menu_aide_installation_choix_base' => 'သင့်အချက်အလက် သိုလှောင်မှုကိုရွေးပါ',
	'module_fichier_langue' => 'ဘာသာစကားဖိုင်',
	'module_raccourci' => 'မာတိကာ',
	'module_texte_affiche' => 'စာသားကိုဖော်ပြပါ',
	'module_texte_explicatif' => 'သင့်ဝက်ဘ်ဆိုက် ပုံစံများတွင် အတိုကောက်စာလုံးများကို ထည့်သွင်းနိုင်သည်။ ၄င်းတို့က ဘာသာစကားဖိုင်တွင်ရှိသော ဘာသာစကားများဖြင့် အလိုလျောက် ဘာသာပြန်ပေးလိမ့်မည်',
	'module_texte_traduction' => 'ဘာသာစကားဖိုင် « @module@ » သည် ရနိုင်သည်',
	'mois_non_connu' => 'အမည်မသိ',

	// O
	'onglet_repartition_actuelle' => 'အခု',

	// P
	'plugin_etat_developpement' => 'ပြုလုပ်ဆဲ',
	'plugin_etat_experimental' => 'စမ်းသပ်သည်',
	'plugin_etat_stable' => 'အတည်တကျ',
	'plugin_etat_test' => 'စမ်းသပ်ပြီး',
	'plugins_liste' => 'ထပ်ပေါင်းပရိုဂရမ်ငယ်စာရင်း',
	'protocole_ldap' => 'Protocol မူကွဲ',

	// R
	'repertoire_plugins' => 'အညွှန်း',
	'required' => '[လိုအပ်ပါသည်]', # MODIF

	// S
	'statut_admin_restreint' => '(ကန့်သတ်​ထားသော ကြီးကြပ်သူ)', # MODIF

	// T
	'taille_cache_image' => 'ရုပ်ပုံများကို  SPIP ဖြင့်တိုက်ရိုက်တွက်ချက်၍မရပါ (နမူနာပုံများ, ဂရပ်ဖစ်သို့ ပြောင်းခြင်းများ, စာသားပုံစံထဲတွင် သင်္ချာဖော်မြူလာများ စသည်) @dir@ ထဲရှိ @taille@  ၏ပေါင်းခြင်းကို အညွှန်းတွင်ပြပါ',
	'taille_cache_octets' => 'မှတ်ဉာဏ်၏ လက်ရှိအရွယ်အစားမှာ @octets@ ဖြစ်သည်', # MODIF
	'taille_cache_vide' => 'မှတ်ထားချက်မရှိပါ',
	'taille_repertoire_cache' => 'မှတ်ဉာဏ်၏ လက်ရှိအရွယ်စား',
	'text_article_propose_publication' => 'ဆောင်းပါးကို ထုတ်ဝေရန် ထည့်သွင်းပြီးဖြစ်သည်၊ ဤဆောင်းပါးတွင် ဖိုရမ်မှသင့်အမြင်ကို တင်ပြနိုင်ပါသည်၊ (စာမျက်နှာအောက်တွင်)', # MODIF
	'texte_acces_ldap_anonyme_1' => 'အချို့ LDAP ဆာဗာများသည် အမည်မသိသော ဝင်ရောက်မှုကို ခွင့်မပြုပါ။ ဤကိစ္စတွင် သတင်းအချက်အလက်များကို နောက်နောင်တွင် လမ်းညွှန်ထဲ၌ ရှာဖွေမှု ပြုနိုင်ရန် ဆက်သွယ်မှု အမှတ်အသားကို ​အရင်ဖော်ပြသင့်သည်။ သို့သော် ဖြစ်စဉ်အများစုတွင် အောက်ပါနေရာများကို ဗလာဖြစ်စေနိုင်သည်',
	'texte_admin_effacer_01' => 'ဤစေခိုင်းချက်သည် အ​ချက်လက်သိုလှောင်မှုတွင် ပါဝင်သော အကြောင်းအရာ  <i>အားလုံး</i>  ကို ဖျက်ပစ်ပါ<i>all</i> စီမံကြီးကြပ်သူနှင့် စားတည်းများ ဝင်ရောက်ဆက်သွယ်ရန် အချက်အလက်များ။ ဤအရာကို စီရင်ပြီးရင်တော့ သိုလှောင်မှုအသစ်ကို ဖန်တီးရန်နှင့် စီမံကြီးကြပ်သူများ ပထမဆုံး ဝင်ရောက်နိုင်ရန် SPIP ကိုပြန်လည် ထည့်သွင်းရန်လိုအပ်သည်။', # MODIF
	'texte_adresse_annuaire_1' => '(သင့်လမ်းညွှန်ကို စက်တခုထဲတွင် ထည့်သွင်းထားပါက ဤသို့ပေါ် «localhost»လိမ့်မည်။)',
	'texte_ajout_auteur' => 'အောက်ပါစာ​ရေးသူကို ဆောင်းပါးနှင့်ချိတ်ဆက်ပြီးဖြစ်သည်',
	'texte_annuaire_ldap_1' => '(LDAP) အညွှန်းကိုအသုံးပြုနိုင်ပါက အောက်ရှိ တင်သွင်းထားသော အသစ်သုံးစွဲသူများကို အလိုအလျောက် အသုံးပြုနိုင်သည်', # MODIF
	'texte_article_statut' => 'ဆောင်းပါးအဆင့်',
	'texte_article_virtuel' => 'အရေးကြီးသော ဆောင်းပါး',
	'texte_article_virtuel_reference' => '<b>အရေးကြီးသော ​ဆောင်းပါ</b> သင့် ဆိုက်ရှိကိုးကား ဆောင်းပါးဖြစ်သော်လည်း အခြားဝက်ဘ်ဆိုက်လိပ်စာသို့ လမ်းလွဲနေသည်၊ အထက်ပါဝက်ဘ်ဆိုက်လိပ်စာကို ဖျက်ပစ်ခြင်းဖြင့် ပြန်တည့်နိုင်သည်',
	'texte_aucun_resultat_auteur' => '\\"@cherche_auteur@\\"အတွက်ရလာဒ်မရှိပါ',
	'texte_auteur_messagerie' => 'ဤဆိုက်သည် ချိတ်ဆက်​ထားသော စာတည်းများကို အဆက်မပြတ်​ စောင့်ကြည့်နိုင်သည်၊ ဤလုပ်ဆောင်ချက်သည် သတင်းစကားများကို ချက်ချင်းဖလှယ်နိုင်ရန် လုပ်ဆောင်ပေးသည်။ ဤစာရင်းထဲတွင် သင့်နာမည် မပါအောင် သင့်မှာရွေးချယ်ခွင့်ရှိသည်။ (သင့်ကိုတခြားသူများမှ မြင်နိုင်မည် မဟုတ်တော့ပါ)', # MODIF
	'texte_auteurs' => 'စာရေးဆရာများ',
	'texte_choix_base_1' => 'သင့်အချက်လက်သိုလှောင်မှုကိုရွေးချယ်ပါ',
	'texte_choix_base_2' => 'MySQL ဆာဗာတွင် အချက်လက်သိုလှောင်မှုများ များစွာပါဝင်သည်',
	'texte_choix_base_3' => '<b>ရွေးချယ်ရန်</b> အောက်တွင်ဖော်ပြသည်မှာ သင့် အင်တာနက် ဝန်ဆောင်မှုပေးသူမှ အေးထားသော အချက်အလက်များဖြစ်သည်။',
	'texte_compte_element' => '@count@ အက္ခရာစဉ်',
	'texte_compte_elements' => '@count@ အက္ခရာစဉ်',
	'texte_connexion_mysql' => 'သင့်ဝက်ဘ်ဆိုက် MySQLနှင့် ဆက်သွယ်မှု ခွင့်ပြုထားလ္ခင် အချက်လက်များကို MySQL ဝက်ဘ်ဆာဗာမှ ပေးထားပြီး ဖြစ်ပါလိမ့်မည်', # MODIF
	'texte_contenu_article' => '(ဆောင်းပါး မာတိကာ အကျဉ်းချုံး)',
	'texte_contenu_articles' => 'ဝက်ဘ်ဆိုက် အခင်းကျင်းပေါ်မူတည်၍ ဆောင်းပါးအမျိုးအစား သုံးသင့်။ မသင့်ရွေးချယ်ပါ၊ အောက်ပါ အမျိုးအစားများကို အသုံးပြုနိုင်ပါသည်',
	'texte_crash_base' => 'အကယ်၍ သင့်အချက်လက်သိုလှောင်မှု ပျက်စီးသွားပါက အလို​လျောက် ပြန်လည်သိုလှောင်ရန်အတွက် ကြိုးစားနိုင်ပါသည်',
	'texte_creer_rubrique' => 'ဆောင်းပါးများကို ရေးသား၍မရမီ<br />အခန်းကဏ္ဍကို အရင်တည်ဆောက်ပါ',
	'texte_date_creation_article' => 'ဆောင်းပါးဖန်တီးသည့် ရက်စွဲ',
	'texte_date_publication_anterieure' => 'အရင်ထုတ်ဝေသည့် ရက်စွဲ',
	'texte_date_publication_anterieure_nonaffichee' => 'အရင်ထုတ်​ဝေသည့် ဆောင်းပါးကို ဖျောက်ထားပါ',
	'texte_date_publication_article' => 'အွန်လိုင်းထုတ်ဝေမှုရက်စွဲ',
	'texte_descriptif_rapide' => 'အကျဉ်းချုပ်ဖော်ပြချက်',
	'texte_effacer_base' => 'SPIP အချက်လက်သိုလှောင်မှုကို ဖျက်ပစ်ပါ',
	'texte_en_cours_validation' => 'အောက်ပါဆောင်းပါးများနှင့် သတင်းများသည် ထုတ်​ဝေရန်ထည့်သွင်းပြီးဖြစ်ပါသည်၊ ၎င်းတွင် ဖိုရမ်များတွဲ၍ သင့်အမြင်ကိုပေးရန်', # MODIF
	'texte_enrichir_mise_a_jour' => '«typographical shortcuts»ကိုအသုံးပြုပြီးသင့်စာသားအခင်းအကျင်းကို ပိုကောင်းအောင်ပြုလုပ်နိုင်ပါသည်',
	'texte_fichier_authent' => '<b>SPIP မှ<tt>.htpasswd</tt> နှင့် <tt>.htpasswd-admin</tt> ဖိုင်များကို လမ်းညွှန် @dossier@ထဲတွင် ဖန်တီးစေလိုပါသလား?</b><p>ဤဖိုင်များသည် ဤဆိုက်​၏ ကန့်သတ်ထားသော တခြားနေရာများတွင် စာရေးသူနှင့် စီမံကြီးကြပ်သူတို့ကို ဝင်ရောက်နိုင်အောင် အသုံးပြုနိုင်သည်။</p><p>ဒီဖိုင်များကို သင်အလိုမရှိဘူးဆိုရင် ဤရွေးချယ်မှုကို ဒီအတိုင်းထားနိုင်သည်။</p>', # MODIF
	'texte_informations_personnelles_1' => 'စနစ်သည်ဆိုက်တွင် စိတ်ကြိုက်ဝင်ရောက်နိုင်ရန် အကူညီပေးပါမည်',
	'texte_informations_personnelles_2' => '(မှတ်စု-အကယ်၍ သည်ဟာသည် ပြန်လည်ထည့်သွင်းခြင်းဖြစ်ပါက သင့်လုပ်ဆောင်ချက်သည် အလုပ်​လုပ်နေဆဲဖြစ်သည်။ သင်လုပ်နိုင်သည်', # MODIF
	'texte_introductif_article' => '(ဆောင်းပါးတွင် စာသားများ အစပြုခြင်း)',
	'texte_jeu_caractere' => 'နိုင်ငံသကာသုံး alphabet (<tt>utf-8</tt>) ကို သင့်ဆိုက်တွင် အသုံးပြုရန် အကြံပြုပါသည်။ ဤသို့ဖြင့် ဘယ်ဘာသာစကားမဆို သင့်ဆိုက်ပေါ်တွင် ​ဖတ်ရှုနိုင်မည်။ ဤ character set နှင့် ပတ်သက်၍ နောက်ဆုံပေါ် ဘယ်browserနှင့် မဆို အဆင်ပြေပါသည်။',
	'texte_jeu_caractere_3' => '​လက်ရှိတွင် သင့်ဝက်ဘ်ဆိုက်က ဤအက္ခရာ သတ်မှတ်ချက်ကို အသုံးပြုနေသည်',
	'texte_jeu_caractere_4' => 'သင့် ​ဒေတာများနှင့် ဆက်နွယ်မှု မရှိဘူးဆိုရင်တော့ (ဥပမာ- အရံသိမ်းဆည်းထားသည့် သိုလှောင်မှုကို ပြန်လည်ထည့်သွင်းပြီးမှ) သို့တည်းမဟုတ် <em>ဤဆိုက်ကိုပြန်လည် တပ်ဆင်ပြီးတော့မှ</em> တခြား character set များကို အသုံးပြုလိုလျှင် ဤနေရာတွင်ဖော်ပြပါ။',
	'texte_login_ldap_1' => '(အမည်မရှိသူများမဝင်ရောက်နိုင်ရန်သိမ်းထားပါ (သို့) «<tt>uid=smith, ou=users, dc=my-domain, dc=com</tt>».) တို့အတွက် ပြည့်စုံသည့်အပိုင်းကို ထည့်သွင်းပါ',
	'texte_login_precaution' => 'သတိပေးချက်-သင်ချိတ်ဆက်ထားသောအရာနှင့် ဝင်ရောက်နိုင်သည်၊ ဤပုံစံကိုဂရုတစိုက်သုံးပါ',
	'texte_mise_a_niveau_base_1' => 'သင့်SPIP ဖိုင်များကို လက်ရှိ​အနေအထားတိုင်း မွမ်းမံပြီးဖြစ်သည်။ ဝက်ဘ်ဆိုက်အချက်လက် သိုလှောင်မှုကို အဆင့်မြှင့်ပြုပြင်ပါ',
	'texte_modifier_article' => 'ဆောင်းပါးကို ပြန်လည်မွမ်းမံ ပြင်ဆင်ပါ',
	'texte_multilinguisme' => 'ဆောင်းပါးများကို ဘာသာစကားအများပြားဖြင့် စီမံလိုပါက ဆောင်းပါးတွင် (သို့) အပိုင်းများတွင် သင့်ဝက်ဆိုက်၏ အမျိုးစားအလိုက် 
ဘာသာစကား ရွေးချယ်နိုင်သည့် မီနူးကို ပြည့်စုံသော ဦးတည်ချက်ဖြင့် ထပ်ထည့်ပါ', # MODIF
	'texte_multilinguisme_trad' => 'ဘာသာပြန်မတူညီသော ဆောင်းပါးတွင် ဆက်နွယ်မှု စီမံခန့်ခွဲခြင်းကိုလည်း သင်ပြုလုပ်နိုင်ပါသည်', # MODIF
	'texte_non_compresse' => '<i>ချုံ့၍မရပါ</i> (သင့်ဆာဗာက သည်ပုံစံကို လက်မခံနိုင်ပါ)',
	'texte_nouvelle_version_spip_1' => ' SPIP မူကွဲကိုသင် အခုသွင်းနေသည်',
	'texte_nouvelle_version_spip_2' => 'ဤမူကွဲ အသစ်သည် တခြားတွေထက် မြှင့်တင်ခြင်းလုပ်ရန် လိုအပ်ပါသည်။ သင်ဟာ ဒီဝက်ဘ်ဆိုက် webmaster ဖြစ်လျှင် ဖိုင် @connect@ ကို ပယ်ဖျက်ပြီး သိုလှောင်မှု ဆက်သွယ်ရေး အချက်အလက်များ မြှင့်တင်ရန် ထည့်သွင်းခြင်းကို ပြန်လည်ပြုလုပ်ပါ။<p>(NB.: သင့်ဆက်သွယ်မှု အချက်အလက်များကို မေ့လျော့​နေလျှင် @connect@ ဖိုင် မဖျက်သိမ်းခင် သေချာမှတ်သားထားပါ!)</p>', # MODIF
	'texte_operation_echec' => 'အရင်စာမျက်နှာသို့ ပြန်သွား၍ အချက်လက် စုဆောင်းမှုတစ်ခုကိုရွေးပါ (သို့) အသစ်ပြုလုပ်ပါ၊ သင့် ဆာဗာကြီးကြပ်သူထံမှ သတင်းအချက်လက်များဖြင့် အတည်ပြုပေးပါ',
	'texte_plus_trois_car' => 'အက္ခရာ သုံးလုံးထက်ပို၍',
	'texte_plusieurs_articles' => ' \\"@cherche_auteur@\\"အတွက်စာရေးသူအမြောက်အများကိုတွေ့ကသည်',
	'texte_port_annuaire' => '(သာမာန်အားဖြင့် ကနဦးသိုမှီးချက်အတိုင်းသင့်လျော်သည်)',
	'texte_presente_plugin' => 'ဤစာမျက်မှာသည် ဆိုက်ပေါ်တွင် ထပ်ထည့်၍ရသော plugins စာရင်းများဖြစ်သည်။ ရွေးချယ်အ​တည်ပြု ထည့်သွင်းရန် သက်ဆိုင်ရာကို ရွေးချယ်ပါ။',
	'texte_proposer_publication' => 'သင့်ဆောင်းပါးပြီးသောအခါ <br /> ထုတဝေရန်အတွက် တင်သွင်းနိုင်သည်',
	'texte_proxy' => 'တချို့မှာ (intranet ကိုယ်ပိုင် networks စသည်) ပူးတွဲချိတ်ဆက်မှု ဆိုက်များနှင့် ချိတ်ဆက်ရန် <i>proxy HTTP</i> ကိုအသုံးပြုရန် လိုအပ်သည်။ 
proxy လိပ်စာကို အောက်တွင်​ဖော်ပြသည့်အတိုင်း ထည့်ပါ <tt><html>http://proxy:8080</html></tt>။ ပုံမှန်အားဖြင့် ကွက်လပ်ထား၍ရသည်။',
	'texte_publication_articles_post_dates' => 'အနာဂတ်တွင်ထုတ်ဝေရန်သတ်မှတ်ပြီးသော ဆောင်းပါးများအတွက်  SPIP ကမည်သည့်စနစ်ကို သုံးသင့်သလဲ',
	'texte_rappel_selection_champs' => '[နေရာကိုမှန်ကန်စွာရွေးချယ်ရန်သတိရပါ]',
	'texte_recalcul_page' => 'စာတစ်မျက်နှာကိုသာပြန်သစ်ရန် « refresh » ကိုသုံး၍ အများသုံးဧရိယာမှပြန်လုပ်ပါ',
	'texte_recuperer_base' => 'အချက်လက်ထိန်းသိမ်းမှုကို ပြန်လည်ပြင်ဆင်ပါ',
	'texte_reference_mais_redirige' => ' SPIP ဝက်ဘ်ဆိုက်ထဲတွင် သင့်ကိုးကားဆောင်းပါးသည် အခြားဝက်ဘ်လိပ်စာသို့လမ်းလွဲသည်',
	'texte_requetes_echouent' => '<b>MySQL ဆက်သွယ်မှုများ အကြောင်းပြချက်မရှိဘဲနှင့် ​ဖျက်တောက်ခြင်းခံရလျှင် သိုလှောင်မှုကိုယ်၌ ပြသနာ တရားခံဖြစ်သည်။</b><p>MySQL ရုတ်တရက်ပျက်စီးခဲ့လျှင် သူ့ဟာသူပြင်ဆင်နိုင်ရန် ပါရှိသည်။ ဤနေရာမှ ပြင်ဆင်မှုလုပ်ဆောင်ရန် နှိပ်ပါ။ အကယ်၍ အဆင်မပြေရင် ဖော်ပြလာသော စာသားများကို သိမ်းဆည်းထားပါ။ ဘယ်အရာများ မှားယွင်းကြောင်းကို ​​​ဖော်ပြပါရှိမည်။</p><p>ပြသနာ တစုံတရာရှိခဲ့ရင် သင့်ဝက်ဘ်ဝန်ဆောင်မှု ​ဆက်သွယ်ပါ။</p>', # MODIF
	'texte_selection_langue_principale' => 'ဤဝက်ဘ်ဆိုက်၏  \\"အဓိကဘာသာစကား\\" အတွက် အောက်ပါတို့ကို ရွေးချယ်နိုင်သည်။ ဤရွေးချယ်မှုက သင့် ဆောင်းပါးကို ရွေးချယ်သော ဘာသာစကားဖြင့်ရေးရန် ကန့်သတ်မထားပါ သို့သော် ဆုံးဖြတ်ခွင့်ပြုထားသည်။ <ul><li> အများသုံးဝက်ဘ်ဆိုက်ရှိ ရက်စွဲအတွက် ပေးမထားသောပုံစံ</li>
<li>စာသားအပြင်အဆင်စနစ် အင်ဂျင်ကို SPIP မှ စာစီရန်အတွက် အသုံးပြုသည်။</li> <li> အများဆိုင်ဝက်ဘ်ဆိုက်၏ ဖိုရမ်တွင်အသုံးပြုထားသော ဘာသာစကား</li> <li> ကိုယ်ပိုင်နေရာတွင်ဖော်ပြသည့် ​အခြားဘာသာစကား</li></ul>',
	'texte_sous_titre' => 'ခေါင်းစဉ်ခွဲ',
	'texte_statistiques_visites' => '(ဘား​အနက်များ၊ ​အနက်ရောင်မျဉ်းကွေး၊ ပျှမ်းမျှအဆင့်)',
	'texte_statut_attente_validation' => 'အတည်ပြုရန် ဆိုင်းငံ့ထားသည်',
	'texte_statut_publies' => 'အွန်လိုင်းတွင်ထုတ်ဝေသည်',
	'texte_statut_refuses' => 'ငြင်းပယ်သည်',
	'texte_suppression_fichiers' => 'SPIP မှတ်ဉာဏ်ထဲရှိ ဖိုင်များအားလုံးကို ဤခိုင်းစေမှု လုပ်ဆောင်ချက်မှ အကုန်လုံးပျယ်ဖျက်မည်။',
	'texte_sur_titre' => 'ထိပ်စည်းခေါင်းစဉ်',
	'texte_table_ok' => 'ဤဇယားအဆင်ပြေသည်',
	'texte_tentative_recuperation' => 'ပြုပြင်ရန်ကြိုးစားသည်',
	'texte_tenter_reparation' => 'အချက်အလက် သိုလှောင်မှုကို ပြုပြင်ရန်ကြိုးစားသည်',
	'texte_test_proxy' => 'ဤပင်မဆာဗာကို စမ်းသပ်ရန် သင်စမ်းသပ်လိုသည့် ဝက်ဘ်ဆိုက်လိပ်စာကို ဖြည့်ပါ',
	'texte_titre_02' => 'အကြောင်းအရာ',
	'texte_titre_obligatoire' => '<b>ခေါင်းစဉ်</b> [လိုအပ်ပါသည်]',
	'texte_travail_article' => '@nom_auteur_modif@သည် ဤဆောင်းပါးတွင် လွန်ခဲ့သော မိနစ် @date_diff@ ကအလုပ်လုပ်ပြီးပြီ',
	'texte_travail_collaboratif' => 'စာတည်းများ ဆောင်းပါးတပုဒ်ပေါ်တွင် အတူတူလုပ်ဆောင်နေပါက၊ မှားယွင်းသော လုပ်ဆောင်မှုများ မဖြစ်ရန်၊ နောက်ဆုံး စာတည်း «opened&raquo ဟုဖော်ပြပါမည်။ ဒီသတိပေး စာစောင်ဟာ အနောက်အယှက်များ မဖြစ်စေရန် ကနဦးမှ ပိတ်ပင်ထားပါသည်။', # MODIF
	'texte_vide' => 'မရှိပါ',
	'texte_vider_cache' => 'မှတ်ထားချက်မရှိပါ',
	'titre_admin_tech' => 'နည်းပညာထိန်းသိမ်းမှု',
	'titre_cadre_afficher_article' => 'ဆောင်းပါးများကို ပြပါ',
	'titre_cadre_afficher_traductions' => 'ဝက်ဘ်ဆိုက်အတွက် ဘာသာပြန်ထားသော အောက်ပါဘာသာစကားများကို ဖော်ပြပါ',
	'titre_cadre_ajouter_auteur' => 'စာရေးသူတဦး​ပေါင်းထည့်ပါ',
	'titre_cadre_interieur_rubrique' => 'အခန်းကဏ္ဍထဲတွင်',
	'titre_cadre_numero_auteur' => 'စာရေးသူအမှတ်',
	'titre_cadre_signature_obligatoire' => '<b>အမှတ်အသား</b> [လိုအပ်ပါသည်]<br />',
	'titre_config_fonctions' => 'ဝက်ဘ်ဆိုက်ဆက်သွယ်တပ်ဆင်မှု',
	'titre_configuration' => 'ဝက်ဘ်ဆိုက်ဆက်သွယ်တပ်ဆင်မှု',
	'titre_connexion_ldap' => 'Options: <b>သင့် LDAP ချိတ်ဆက်မှု</b>',
	'titre_groupe_mots' => 'သော့ချက်စကားလုံးအုပ်စု',
	'titre_langue_article' => 'ဆောင်းပါးဘာသာစကား', # MODIF
	'titre_langue_rubrique' => 'အခန်းကဏ္ဍဘာသာစကား', # MODIF
	'titre_langue_trad_article' => 'ဆောင်းပါး ဘာသာနှင့် ဘာသာပြန်ခြင်း',
	'titre_les_articles' => 'ဆောင်းပါးများ',
	'titre_naviguer_dans_le_site' => 'ဤဝက်ဘ်ဆိုက်သွားပါ',
	'titre_nouvelle_rubrique' => 'အခန်းကဏ္ဍမသစ်',
	'titre_numero_rubrique' => 'အခန်းကဏ္ဍအမှတ်',
	'titre_page_articles_edit' => '@titre@ကို ပြန်လည်မွမ်းမံပါ',
	'titre_page_articles_page' => 'ဆောင်းပါးများ',
	'titre_page_articles_tous' => 'ဝက်ဘ်ဆိုက်တခုလုံး',
	'titre_page_calendrier' => 'ပြက္ခဒိန် @nom_mois@ @annee@',
	'titre_page_config_contenu' => 'ဝက်ဘ်ဆိုက်ဆက်သွယ်တပ်ဆင်မှု',
	'titre_page_delete_all' => 'ထာဝရဖျက်သိမ်းခြင်း',
	'titre_page_recherche' => '@recherche@အတွက်ရှာဖွေမှုရလာဒ်',
	'titre_page_statistiques_referers' => 'ဝင်လာသော ဆက်နွယ်မှုစာရင်းများ',
	'titre_page_upgrade' => 'SPIP မြှင့်တင်မှု',
	'titre_publication_articles_post_dates' => 'ရက်လွန်ဆောင်းပါးများ​ထုတ်ဝေခြင်း',
	'titre_reparation' => 'ပြန်လည်ပြင်ဆင်သည်',
	'titre_suivi_petition' => 'နောက်ဆက်တွဲတောင်းဆိုမှု',
	'tls_ldap' => 'ပို့ဆောင်မှုအလွှာ လုံခြုံရေး',
	'trad_article_traduction' => 'ဤဆောင်းပါး၏ မူကွဲအားလုံး',
	'trad_delier' => 'ဤဆောင်းပါးနှင့် ၄င်း၏ ဘာသာပြန် ချိတ်ဆက်မှု ရပ်ဆိုင်းပါ', # MODIF
	'trad_lier' => 'ဤဆောင်းပါးသည် ဆောင်းပါးအမှတ် ကိုဘာသာပြန်ခြင်းဖြစ်သည်',
	'trad_new' => 'ဤဆောင်းပါးကို ပြန်လည်ဘာသာပြန်ပါ', # MODIF

	// U
	'utf8_convert_erreur_orig' => 'အမှား- အက္ခရာထားရှိမှု @charset@ ကို သုံး၍မရပါ',

	// V
	'version' => 'မူကွဲ',
];
